#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2023/3/22 15:21
# @Author  : unclear
# @File    : usage.py
# @Software: PyCharm
from time import ctime

from testpg import __version__


def run():
    cur_time = ctime()
    text = f"""
    # testpg

    version {__version__} ({cur_time} +0800)
    """
    print(text)


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2023/3/22 15:20
# @Author  : unclear
# @File    : __init__.py.py
# @Software: PyCharm
__version__ = "0.0.1"

from testpg import shell, src

__all__ = [
    "__version__",
    "shell",
    "src"
]



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2023/3/22 15:20
# @Author  : unclear
# @File    : __init__.py.py
# @Software: PyCharm
from testpg.shell.usage import run

__all__ = [
    "run"
]


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2023/3/22 15:34
# @Author  : unclear
# @File    : __init__.py.py
# @Software: PyCharm
from package_name.src import demo

__all__ = [
    "demo"
]